@@ -4,40 +4,12 @@ from rhetoric.view import RegexURLPattern
 from django.core.urlresolvers import reverse
 
 
-#A replacement marker in a pattern must begin with an uppercase or
+# A replacement marker in a pattern must begin with an uppercase or
 # lowercase ASCII letter or an underscore, and can be composed only
 # of uppercase or lowercase ASCII letters, underscores, and numbers.
 # For example: a, a_b, _b, and b9 are all valid replacement marker names, but 0a is not.
 ROUTE_PATTERN_OPEN_BRACES_RE = re.compile('(?P<start_brace>\{).*')
 ROUTE_PATTERN_CLOSING_BRACES_RE = re.compile('\}.*')
-QUOTES_RE = re.compile('(?P<quote_type>\'\'\'|"""|\'|").*') # order matters!
-
-
-def search_quotes(line, escape_char='\\', quotes_re=QUOTES_RE):
-    """
-    This function is taken from Plim package: https://pypi.python.org/pypi/Plim/
-
-    ``line`` may be empty
-
-    :param line:
-    :param escape_char:
-    """
-    match = quotes_re.match(line)
-    if not match: return None
-
-    find_seq = match.group('quote_type')
-    find_seq_len = len(find_seq)
-    pos = find_seq_len
-    line_len = len(line)
-
-    while pos < line_len:
-        if line[pos] == escape_char:
-            pos += 2
-            continue
-        if line[pos:].startswith(find_seq):
-            return pos + find_seq_len
-        pos += 1
-    return None
 
 
 def _extract_braces_expression(line, starting_braces_re, open_braces_re, closing_braces_re):
@@ -75,12 +47,6 @@ def _extract_braces_expression(line, starting_braces_re, open_braces_re, closing
             tail = tail[1:]
             continue
 
-        result = search_quotes(tail)
-        if result is not None:
-            buf.append(tail[:result])
-            tail = tail[result:]
-            continue
-
         buf.append(current_char)
         tail = tail[1:]
     raise Exception("Unexpected end of a route definition: {}".format(line))
@@ -95,6 +61,18 @@ extract_pattern = lambda line: _extract_braces_expression(
 
 
 def create_django_route(name, pattern, rules=None, extra_kwargs=None, viewlist=None):
+    """
+
+    :param name: Route Name
+    :type name: str
+    :param pattern: URL pattern
+    :type pattern: str
+    :param rules:
+    :type rules: dict
+    :param extra_kwargs:
+    :param viewlist:
+    :return:
+    """
     if rules is None:
         rules = {}
     # Django requires us to strip a prefixed slash
@@ -135,4 +113,11 @@ def create_django_route(name, pattern, rules=None, extra_kwargs=None, viewlist=N
 
 
 def route_path(route_name, *elements, **kw):
+    """
+
+    :param route_name:
+    :param elements:
+    :param kw:
+    :return:
+    """
     return reverse(route_name, args=elements, kwargs=kw)
